meanROIs: The average time series of each ROI

Description Usage Arguments Details Value Author(s) References See Also Examples

Description

Computing the average time series of each ROI in the given EPI sequence

Usage

1
2
meanROIs(EPIfname, nROIs = 31, ROIdir = "", prefix = "roi_", 
     outfname = "meanROIs", writefile = TRUE)

Arguments

EPIfname

the file name of a EPI sequence (The file format should be ANALYZE such as hdr and img. For example, if the original file is "foo.img", the input value should be "foo".)

nROIs

the number of ROIs. Default is 31.

ROIdir

the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory.

prefix

the common prefix of ROI definition files. Default is roi_. Then, the files should be titled as roi_1.nii.gz, roi_2.nii.gz, and so forth.

outfname

the outout text file name. Default is meanROIs.

writefile

Enable to write the output text file. Default is TRUE.

Details

This function computes the average time series of each ROI in the given EPI sequence. The ROI definition files should be given a priori.

Value

A matrix of averaged time series for ROIs. Row indicates a time point, and column does an ROI.

Author(s)

Wonsang You

References

Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.

See Also

tsROI

Examples

1
mts<-meanROIs("foo")

wonsang/easyFMRI documentation built on May 14, 2019, 9:25 p.m.