orthoROIs: Orthogonalization of ROIs

Description Usage Arguments Details Value Author(s) References Examples

Description

Orthogonalizes ROIs in the EPI sequence. In other words, it eliminates all overlapped parts among ROIs, and then creates new ROIs which are spatially independent each other.

Usage

1
2
3
4
orthoROIs(nROIs = 31, ThRes = 5, ROIdir = "", 
      targetdir = "newROIs", mode = "minimal", prefix = "roi_", 
      newprefix = "roi_", writefile = TRUE, gzipped = TRUE, 
      verbose = TRUE)

Arguments

nROIs

the number of ROIs

ThRes

the resolution of threshold. It is applied only when you choose the mode as thresholding. For example, if ThRes=5, the precision becomes 1e-5. Default is 5.

ROIdir

the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory.

targetdir

the directory of output ROI definition files. Default is newROIs.

mode

the mode of orthogonalization. thres denotes thresholding, and minimal denotes minimal overlapping elimination. Default is minimal.

prefix

the common prefix of ROI definition files. Default is roi_. Then, the files should be titled as roi_1.nii.gz, roi_2.nii.gz, and so forth.

newprefix

the common prefix of output ROI definition files. Default is roi_.

writefile

Enable to write the output text file. Default is TRUE.

gzipped

Enable out NIFTI file to be zipped. Default is TRUE.

verbose

Allows message notification duringexecution of the function.

Details

ROIs is normally defined from the anatomical high-resolution image of the brain. To define the ROIs in the EPI sequence, the Brain Voyager can be exploited, however it can cause seriosu distortion such as spatial and temporal blurring. To avoid temporal blurring, we can match each ROI into the EPI space through rotation, translation, and resampling. In this case, overlaps among ROIs can be generated. This function resizes all ROIs by eliminating all overlapped parts.

Value

ROIData

A list of matrices of ROI data. Each matrix is three-dimensional, and indicates a segmented ROI region at the 3D volume of FMRI data. The number of matrices is the same as the number of ROIs.

thr

A vector of thresholds of ROIs. Notice that each ROI can have different threshold. The length of this vector is the same as the number of ROIs.

nOverlapROIpairs

An integer which indicates the number of overlapped ROI pairs.

nOverlapVoxels

An integer which indicates the number of overalpped voxels.

nNewOverlapROIpairs

An integer which indicates the number of overlapped ROI pairs after orthogonalization. In general, it is expected to be zero.

nNewOverlapVoxels

An integer which indicates the number of overalpped voxels after orthogonalization. In general, it is expected to be zero.

Author(s)

Wonsang You

References

Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.

Examples

1
dat<-orthoROIs()

wonsang/easyFMRI documentation built on May 14, 2019, 9:25 p.m.