tsROI: Extraction of ROI Time Series

Description Usage Arguments Details Value Author(s) References See Also Examples

Description

Extracts a set of time series which belong to a predefined ROI in the given EPI sequence.

Usage

1
2
tsROI(ROIidx, EPIfname, ROIdir = "", prefix = "roi_", 
       outfname = "tsROI", writefile = TRUE)

Arguments

ROIidx

the index of ROI

EPIfname

the file name of a EPI sequence (The file format should be ANALYZE such as hdr and img. For example, if the original file is "foo.img", the input value should be "foo".)

ROIdir

the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory.

prefix

the common prefix of ROI definition files. Default is roi_. Then, the files should be titled as roi_1.nii.gz, roi_2.nii.gz, and so forth.

outfname

the outout text file name. Default is tsROI.

writefile

Enable to write the output text file. Default is TRUE.

Details

This function extracts a set of time series of a predefined ROI in the given EPI sequence. The ROI definition file should be given a priori.

Value

A matrix of time series in a ROI. Row indicates a time point, and column does a voxel in the ROI.

Author(s)

Wonsang You

References

Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.

See Also

meanROIs

Examples

1
mts<-meanROIs(10,"foo")

wonsang/easyFMRI documentation built on May 14, 2019, 9:25 p.m.