Description Usage Arguments Details Value Author(s) References See Also Examples
Computing the average time series of each ROI in the given EPI sequence
1 2 |
EPIfname |
the file name of a EPI sequence (The file format should be ANALYZE such as |
nROIs |
the number of ROIs. Default is |
ROIdir |
the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory. |
prefix |
the common prefix of ROI definition files. Default is |
outfname |
the outout text file name. Default is |
writefile |
Enable to write the output text file. Default is |
This function computes the average time series of each ROI in the given EPI sequence. The ROI definition files should be given a priori.
A matrix of averaged time series for ROIs. Row indicates a time point, and column does an ROI.
Wonsang You
Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.
1 | mts<-meanROIs("foo")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.