Description Usage Arguments Details Value Author(s) References Examples
Orthogonalizes ROIs in the EPI sequence. In other words, it eliminates all overlapped parts among ROIs, and then creates new ROIs which are spatially independent each other.
1 2 3 4 |
nROIs |
the number of ROIs |
ThRes |
the resolution of threshold. It is applied only when you choose the mode as thresholding. For example, if |
ROIdir |
the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory. |
targetdir |
the directory of output ROI definition files. Default is |
mode |
the mode of orthogonalization. |
prefix |
the common prefix of ROI definition files. Default is |
newprefix |
the common prefix of output ROI definition files. Default is |
writefile |
Enable to write the output text file. Default is |
gzipped |
Enable out NIFTI file to be zipped. Default is |
verbose |
Allows message notification duringexecution of the function. |
ROIs is normally defined from the anatomical high-resolution image of the brain. To define the ROIs in the EPI sequence, the Brain Voyager can be exploited, however it can cause seriosu distortion such as spatial and temporal blurring. To avoid temporal blurring, we can match each ROI into the EPI space through rotation, translation, and resampling. In this case, overlaps among ROIs can be generated. This function resizes all ROIs by eliminating all overlapped parts.
ROIData |
A list of matrices of ROI data. Each matrix is three-dimensional, and indicates a segmented ROI region at the 3D volume of FMRI data. The number of matrices is the same as the number of ROIs. |
thr |
A vector of thresholds of ROIs. Notice that each ROI can have different threshold. The length of this vector is the same as the number of ROIs. |
nOverlapROIpairs |
An integer which indicates the number of overlapped ROI pairs. |
nOverlapVoxels |
An integer which indicates the number of overalpped voxels. |
nNewOverlapROIpairs |
An integer which indicates the number of overlapped ROI pairs after orthogonalization. In general, it is expected to be zero. |
nNewOverlapVoxels |
An integer which indicates the number of overalpped voxels after orthogonalization. In general, it is expected to be zero. |
Wonsang You
Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.
1 | dat<-orthoROIs()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.