Description Usage Arguments Details Value Author(s) References See Also Examples
Extracts a set of time series which belong to a predefined ROI in the given EPI sequence.
1 2 |
ROIidx |
the index of ROI |
EPIfname |
the file name of a EPI sequence (The file format should be ANALYZE such as |
ROIdir |
the directory of ROI definition files. These files should contain the individual zipped NIFTI files (nii.gz) corresponding to ROIs. Default is current working directory. |
prefix |
the common prefix of ROI definition files. Default is |
outfname |
the outout text file name. Default is |
writefile |
Enable to write the output text file. Default is |
This function extracts a set of time series of a predefined ROI in the given EPI sequence. The ROI definition file should be given a priori.
A matrix of time series in a ROI. Row indicates a time point, and column does a voxel in the ROI.
Wonsang You
Wonsang You (2010) ROI Data Extraction from FMRI BOLD Signals of the Human Brain, Technical Reports of the Leibniz Institute for Neurobiology, TR 10016.
1 | mts<-meanROIs(10,"foo")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.